Index: chrome/common/render_messages.h |
diff --git a/chrome/common/render_messages.h b/chrome/common/render_messages.h |
index 12d7c45455c8fa176122d16f628f7c8a1be1a586..625a4b3a9f4b84d418571580656469758535661f 100644 |
--- a/chrome/common/render_messages.h |
+++ b/chrome/common/render_messages.h |
@@ -146,9 +146,9 @@ IPC_MESSAGE_ROUTED3(ChromeViewMsg_UpdateBrowserControlsState, |
IPC_MESSAGE_ROUTED1(ChromeViewMsg_SetWindowFeatures, |
blink::mojom::WindowFeatures /* window_features */) |
-// Requests application info for the page. The renderer responds back with |
-// ChromeViewHostMsg_DidGetWebApplicationInfo. |
-IPC_MESSAGE_ROUTED0(ChromeViewMsg_GetWebApplicationInfo) |
+// Requests application info for the frame. The renderer responds back with |
+// ChromeFrameHostMsg_DidGetWebApplicationInfo. |
+IPC_MESSAGE_ROUTED0(ChromeFrameMsg_GetWebApplicationInfo) |
// chrome.principals messages ------------------------------------------------ |
@@ -327,7 +327,7 @@ IPC_MESSAGE_ROUTED2(ChromeViewHostMsg_BlockedUnauthorizedPlugin, |
// a secure page by a security policy. The page may appear incomplete. |
IPC_MESSAGE_ROUTED0(ChromeViewHostMsg_DidBlockDisplayingInsecureContent) |
-IPC_MESSAGE_ROUTED1(ChromeViewHostMsg_DidGetWebApplicationInfo, |
+IPC_MESSAGE_ROUTED1(ChromeFrameHostMsg_DidGetWebApplicationInfo, |
WebApplicationInfo) |
// Tells the renderer a list of URLs which should be bounced back to the browser |